mathtools.Ratio
===============

.. abjad-lineage:: abjad.tools.mathtools.Ratio.Ratio

.. autoclass:: abjad.tools.mathtools.Ratio.Ratio

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.mathtools.Ratio.Ratio.count
      ~abjad.tools.mathtools.Ratio.Ratio.index
      ~abjad.tools.mathtools.Ratio.Ratio.__add__
      ~abjad.tools.mathtools.Ratio.Ratio.__contains__
      ~abjad.tools.mathtools.Ratio.Ratio.__eq__
      ~abjad.tools.mathtools.Ratio.Ratio.__format__
      ~abjad.tools.mathtools.Ratio.Ratio.__ge__
      ~abjad.tools.mathtools.Ratio.Ratio.__getitem__
      ~abjad.tools.mathtools.Ratio.Ratio.__getslice__
      ~abjad.tools.mathtools.Ratio.Ratio.__gt__
      ~abjad.tools.mathtools.Ratio.Ratio.__hash__
      ~abjad.tools.mathtools.Ratio.Ratio.__iter__
      ~abjad.tools.mathtools.Ratio.Ratio.__le__
      ~abjad.tools.mathtools.Ratio.Ratio.__len__
      ~abjad.tools.mathtools.Ratio.Ratio.__lt__
      ~abjad.tools.mathtools.Ratio.Ratio.__mul__
      ~abjad.tools.mathtools.Ratio.Ratio.__ne__
      ~abjad.tools.mathtools.Ratio.Ratio.__new__
      ~abjad.tools.mathtools.Ratio.Ratio.__repr__
      ~abjad.tools.mathtools.Ratio.Ratio.__rmul__
      ~abjad.tools.mathtools.Ratio.Ratio.__str__

Bases
-----

- :py:class:`mathtools.NonreducedRatio <abjad.tools.mathtools.NonreducedRatio.NonreducedRatio>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.tuple <tuple>`

- :py:class:`__builtin__.object <object>`

Methods
-------

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.count
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.index
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.__add__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.__contains__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.__eq__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.__format__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.__ge__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.__getitem__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.__getslice__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.__gt__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.__hash__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.__iter__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.__le__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.__len__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.__lt__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.__mul__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.__ne__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.__new__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.__repr__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.__rmul__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.__str__
   :noindex:
